/*
 * Copyright 2015 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
*/

package org.kie.workbench.common.screens.social.hp.client;

import javax.annotation.PostConstruct;

import org.jboss.errai.ioc.client.api.EntryPoint;
import org.kie.workbench.common.screens.social.hp.client.resources.ContainerResources;
import org.uberfire.client.views.pfly.sys.PatternFlyBootstrapper;

@EntryPoint
public class SocialHomePageEntryPoint {

    @PostConstruct
    public void startApp() {
        ContainerResources.INSTANCE.CSS().ensureInjected();
        PatternFlyBootstrapper.ensureBootstrapSelectIsAvailable();
    }
}
